/*! svg4everybody v2.0.0 | github.com/jonathantneal/svg4everybody */

function embed(svg, g) {
	if (g) {
		var viewBox = !svg.getAttribute('viewBox') && g.getAttribute('viewBox');
		var fragment = document.createDocumentFragment();
		var clone = g.cloneNode(true);

		if (viewBox) {
			svg.setAttribute('viewBox', viewBox);
		}

		while (clone.childNodes.length) {
			fragment.appendChild(clone.firstChild);
		}

		svg.appendChild(fragment);
	}
}

function createSvgElement(xhr) {
	var xElement;

	if (typeof xhr._elementCache === 'undefined') {
		xhr._elementCache = {};
	}

	if (typeof xhr._elementCache[xhr.responseURL] === 'undefined') {
		xElement = document.createElement('x');
		xElement.innerHTML = xhr.responseText;
		xhr._elementCache[xhr.responseURL] = xElement;
	} else {
		xElement = xhr._elementCache[xhr.responseURL];
	}

	xhr.s.splice(0).map(function (array) {
		embed(array[0], xElement.querySelector('#' + array[1].replace(/(\W)/g, '\\$1')));
	});
}

function loadreadystatechange(xhr) {
	xhr.onreadystatechange = function () {
		if (xhr.readyState === 4) {
			createSvgElement(xhr);
		}
	};

	xhr.onreadystatechange();
}

function svg4everybody(rawopts) {
	var opts = rawopts || {};

	var uses = document.getElementsByTagName('use');
	var nosvg;
	var fallback;

	if (LEGACY_SUPPORT) {
		fallback = opts.fallback || function (src) {
			return src.replace(/\?[^#]+/, '').replace('#', '.').replace(/^\./, '') + '.png' + (/\?[^#]+/.exec(src) || [''])[0];
		};

		nosvg = 'nosvg' in opts ? opts.nosvg : /\bMSIE [1-8]\b/.test(navigator.userAgent);

		if (nosvg) {
			document.createElement('svg');
			document.createElement('use');
		}
	}

	var polyfill = 'polyfill' in opts ? opts.polyfill : LEGACY_SUPPORT ? nosvg || /\bEdge\/12\b|\bMSIE [1-8]\b|\bTrident\/[567]\b|\bVersion\/7.0 Safari\b/.test(navigator.userAgent) || (navigator.userAgent.match(/AppleWebKit\/(\d+)/) || [])[1] < 537 : /\bEdge\/12\b|\bTrident\/[567]\b|\bVersion\/7.0 Safari\b/.test(navigator.userAgent) || (navigator.userAgent.match(/AppleWebKit\/(\d+)/) || [])[1] < 537;

	var validate = opts.validate;
	var requestAnimationFrame = window.requestAnimationFrame || setTimeout;
	var svgCache = {};

	function oninterval() {
		var use;
		var svg;
		var i = 0;

		while (i < uses.length) { // "uses" array maybe change length in the loop
			use = uses[i];
			svg = use.parentNode;

			if (svg && /svg/i.test(svg.nodeName)) {
				var src = use.getAttribute('xlink:href');

				if (LEGACY_SUPPORT && nosvg) {
					var img = new Image();
					var width = svg.getAttribute('width');
					var height = svg.getAttribute('height');

					img.src = fallback(src, svg, use);

					if (width) {
						img.setAttribute('width', width);
					}

					if (height) {
						img.setAttribute('height', height);
					}

					svg.replaceChild(img, use);
				} else if (polyfill) {
					if (!validate || validate(src, svg, use)) {
						var url = src.split('#');
						var urlRoot = url[0];
						var urlHash = url[1];

						svg.removeChild(use);

						if (urlRoot.length) {
							var xhr = svgCache[urlRoot] = svgCache[urlRoot] || new XMLHttpRequest();

							if (!xhr.s) {
								xhr.s = [];

								xhr.open('GET', urlRoot);

								xhr.send();
							}

							xhr.s.push([svg, urlHash]);

							loadreadystatechange(xhr);
						} else {
							embed(svg, document.getElementById(urlHash));
						}
					}
				}
			} else {
				// increase it only if the previous value was not "valid"
				i += 1;
			}
		}

		requestAnimationFrame(oninterval, 67);
	}

	if (polyfill) {
		oninterval();
	}
}
